__prog__ = 'pytest-hue'
__author__ = 'Colin Wren'
__email__ = 'gimpneek@gmail.com'
__url__ = 'https://github.com/Gimpneek/pytest-hue'
__copyright__ = 'copyright 2019 pytest-hue contributors'
__license__ = 'GPLv3'
__description__ = 'Visualise PyTest status via your Phillips Hue lights'
__keywords__ = 'py.test pytest phillips hue lights report'
__version__ = '1.0.0'
